<?php
/**
 * @version        6.7.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2023 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use OSSolution\PaymentForm\Site\Helper\PaymentMethods as PaymentMethodsHelper;

defined('_JEXEC') or die;

HTMLHelper::_('bootstrap.tooltip', '.hasTooltip', array('placement' => 'top'));

$isJoomla4        = PMFormHelper::isJoomla4();
$cols             = 7;
$showFirstName    = false;
$showLastName     = false;
$showOrganization = false;

if (in_array('first_name', $this->coreFields))
{
	$cols++;
	$showFirstName = true;
}

if (in_array('last_name', $this->coreFields))
{
	$cols++;
	$showLastName = true;
}

if (in_array('organization', $this->coreFields))
{
	$cols++;
	$showOrganization = true;
}


if ($this->config->show_coupon)
{
	$cols++;
}

Factory::getDocument()->addScript(Uri::root(true) . '/media/com_pmform/js/admin-payments-default.min.js');
Text::script('PF_PLEASE_SELECT_FORM', true);
?>
<form action="index.php?option=com_pmform&view=payments" method="post" name="adminForm" id="adminForm">
	<div class="row-fluid">
		<div id="j-sidebar-container" class="span2">
			<?php echo $this->sidebar; ?>
		</div>
		<div id="j-main-container" class="span10">
            <div id="filter-bar" class="btn-toolbar<?php if ($isJoomla4) echo ' js-stools-container-filters-visible'; ?>">
				<div class="filter-search btn-group pull-left">
					<label for="filter_search" class="element-invisible"><?php echo Text::_('PF_SEARCH_PAYMENTS_DESC');?></label>
					<input type="text" name="filter_search" id="filter_search" placeholder="<?php echo Text::_('JSEARCH_FILTER'); ?>" value="<?php echo $this->escape($this->state->filter_search); ?>" class="hasTooltip form-control" title="<?php echo HTMLHelper::tooltipText('PF_FILTER_SEARCH_PAYMENTS_DESC'); ?>" />
				</div>
				<div class="btn-group pull-left">
					<button type="submit" class="btn<?php if ($isJoomla4) echo ' btn-primary'; ?> hasTooltip" title="<?php echo HTMLHelper::tooltipText('JSEARCH_FILTER_SUBMIT'); ?>"><span class="icon-search"></span></button>
					<button type="button" class="btn<?php if ($isJoomla4) echo ' btn-primary'; ?> hasTooltip" title="<?php echo HTMLHelper::tooltipText('JSEARCH_FILTER_CLEAR'); ?>" onclick="document.getElementById('filter_search').value='';this.form.submit();"><span class="icon-remove"></span></button>
				</div>
                <div class="btn-group pull-left">
		            <?php echo PMFormHelper::getChoicesJsSelect($this->lists['filter_form_id']); ?>
                </div>
				<div class="btn-group pull-right hidden-phone">
					<?php
                        foreach ($this->filters as $filter)
                        {
                            echo $filter;
                        }
						echo $this->lists['filter_state'];
						echo $this->pagination->getLimitBox();
					?>
				</div>
			</div>
			<table class="adminlist table table-stripped">
				<thead>
				<tr>
					<th width="5">
						<?php echo Text::_( 'NUM' ); ?>
					</th>
					<th width="20">
						<input type="checkbox" name="toggle" value="" onclick="Joomla.checkAll(this);" />
					</th>
					<th class="title" style="text-align: left">
						<?php echo HTMLHelper::_('grid.sort',  'PF_FORM', 'b.title', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
					</th>
                    <?php
                        if ($showFirstName)
                        {
                        ?>
                            <th class="title" style="text-align: left">
		                        <?php echo HTMLHelper::_('grid.sort',  'PF_FIRST_NAME', 'tbl.first_name', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
                            </th>
                        <?php
                        }

						if ($showLastName)
						{
						?>
							<th class="title" style="text-align: left;">
								<?php echo HTMLHelper::_('grid.sort',  'PF_LAST_NAME', 'tbl.last_name', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
							</th>
						<?php
						}

						if ($showOrganization)
						{
						?>
							<th class="title" style="text-align: left;">
								<?php echo HTMLHelper::_('grid.sort',  'PF_ORGANIZATION', 'tbl.organization', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
							</th>
						<?php
						}
					?>
					<th class="center">
						<?php echo HTMLHelper::_('grid.sort',  'PF_PAYMENT_DATE', 'tbl.created_date', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
					</th>
					<th class="title">
						<?php echo HTMLHelper::_('grid.sort',  'PF_AMOUNT', 'tbl.gross_amount', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
					</th>
					<?php
					if ($this->config->show_coupon)
					{
					?>
						<th class="title">
							<?php echo HTMLHelper::_('grid.sort',  'PF_COUPON_CODE', 'd.code', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
						</th>
					<?php
					}
					?>
					<th class="title">
						<?php echo HTMLHelper::_('grid.sort',  'PF_PAID', 'tbl.published', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
					</th>
					<?php
					if ($this->config->activate_invoice_feature)
					{
					    $cols++;
					?>
						<th width="8%">
							<?php echo HTMLHelper::_('grid.sort',  Text::_('PF_INVOICE_NUMBER'), 'tbl.invoice_number', $this->state->filter_order_Dir, $this->state->filter_order); ?>
						</th>
					<?php
					}

					foreach($this->fields as $field)
					{
					    $cols++;
					?>
                        <th><?php echo $field->title; ?></th>
					<?php
					}
					?>
					<th width="1%" nowrap="nowrap">
						<?php echo HTMLHelper::_('grid.sort',  'ID', 'tbl.id', $this->state->filter_order_Dir, $this->state->filter_order ); ?>
					</th>
				</tr>
				</thead>
				<tfoot>
				<tr>
					<td colspan="<?php echo $cols ; ?>">
						<?php echo $this->pagination->getListFooter(); ?>
					</td>
				</tr>
				</tfoot>
				<tbody>
				<?php
				$k = 0;
				for ($i=0, $n=count( $this->items ); $i < $n; $i++)
				{
					$row       = $this->items[$i];
					$link      = Route::_('index.php?option=com_pmform&task=payment.edit&id=' . $row->id);
					$checked   = HTMLHelper::_('grid.id', $i, $row->id);
					$published = HTMLHelper::_('jgrid.published', $row->published, $i);
					?>
					<tr class="<?php echo "row$k"; ?>">
						<td>
							<?php echo $this->pagination->getRowOffset( $i ); ?>
						</td>
						<td>
							<?php echo $checked; ?>
						</td>
						<td>
							<a href="<?php echo $link; ?>"><?php echo $row->title ; ?></a>
						</td>
                        <?php
                            if ($showFirstName)
                            {
                            ?>
                                <td>
                                    <a href="<?php echo $link; ?>">
			                            <?php
			                            echo $row->first_name;

			                            if ($row->user_id)
			                            {
				                        ?>
                                            (<a href="index.php?option=com_users&task=user.edit&id=<?php echo $row->user_id; ?>">
				                                <?php echo $row->payer_username; ?>
                                            </a>)
				                        <?php
			                            }
			                            ?>
                                    </a>
                                </td>
                            <?php
                            }

                            if ($showLastName)
							{
							?>
								<td>
									<a href="<?php echo $link; ?>">
										<?php echo $row->last_name; ?>
									</a>
								</td>
							<?php
							}

							if ($showOrganization)
							{
							?>
								<td>
									<?php echo $row->organization; ?>
								</td>
							<?php
							}
						?>
						<td class="center">
                            <?php
                                if ((int) $row->created_date)
                                {
	                                echo  HTMLHelper::_('date', $row->created_date, $this->config->date_format, null);
                                }
                            ?>
						</td>
						<td class="center">
							<?php echo  PMFormHelper::formatAmount($row->gross_amount, $this->config); ?>
						</td>
						<?php
						if ($this->config->show_coupon)
						{
						?>
							<td>
								<?php echo $row->coupon_code ; ?>
							</td>
						<?php
						}
						?>
						<td class="center">
							<?php echo $published ; ?>
						</td>
						<?php
						if ($this->config->activate_invoice_feature)
						{
						?>
							<td class="center">
								<?php
								if ($row->invoice_number)
								{
								?>
									<a href="<?php echo Route::_('index.php?option=com_pmform&task=payment.download_invoice&id='.$row->id); ?>" title="<?php echo Text::_('PM_DOWNLOAD'); ?>"><?php echo PMFormHelper::formatInvoiceNumber($row->invoice_number, $this->config) ; ?></a>
								<?php
								}
								?>
							</td>
						<?php
						}

						foreach($this->fields as $field)
						{
						    $name = $field->name;
						    if ($field->is_core)
                            {
                                $fieldValue = $row->{$name};
                            }
                            elseif (isset($this->fieldsData[$row->id][$field->id]))
                            {
                                $fieldValue = $this->fieldsData[$row->id][$field->id];
                            }
                            else
                            {
                                $fieldValue = '';
                            }
						?>
                            <th><?php echo $fieldValue; ?></th>
						<?php
						}
						?>
						<td class="center">
							<?php echo $row->id; ?>
						</td>
					</tr>
					<?php
					$k = 1 - $k;
				}
				?>
				</tbody>
			</table>
		</div>
		<div class="clearfix"></div>
	</div>
	<input type="hidden" name="task" value="" />
	<input type="hidden" name="boxchecked" value="0" />
	<input type="hidden" name="filter_order" value="<?php echo $this->state->filter_order; ?>" />
	<input type="hidden" name="filter_order_Dir" value="<?php echo $this->state->filter_order_Dir; ?>" />
	<?php echo HTMLHelper::_( 'form.token' ); ?>
</form>